@@ -38,6 +38,7 @@ extern int apcsmart_ups_get_capabilities(UPSINFO *ups);
 extern int apcsmart_ups_read_volatile_data(UPSINFO *ups);
 extern int apcsmart_ups_read_static_data(UPSINFO *ups);
 extern int apcsmart_ups_kill_power(UPSINFO *ups);
+extern int apcsmart_ups_shutdown(UPSINFO *ups);
 extern int apcsmart_ups_check_state(UPSINFO *ups);
 extern int apcsmart_ups_open(UPSINFO *ups);
 extern int apcsmart_ups_close(UPSINFO *ups);
@@ -45,4 +46,8 @@ extern int apcsmart_ups_setup(UPSINFO *ups);
 extern int apcsmart_ups_program_eeprom(UPSINFO *ups, int command, const char *data);
 extern int apcsmart_ups_entry_point(UPSINFO *ups, int command, void *data);
 
+extern int apcsmart_ups_shutdown_with_delay(UPSINFO *ups, int shutdown_delay);
+extern int apcsmart_ups_get_shutdown_delay(UPSINFO *ups);
+extern void apcsmart_ups_warn_shutdown(UPSINFO *ups, int shutdown_delay);
+
 #endif   /* _APCSMART_H */
