@@ -67,7 +67,7 @@ int apcsmart_ups_open(UPSINFO *ups)
 #endif
 
    if ((ups->fd = open(opendev, O_RDWR | O_NOCTTY | O_NDELAY | O_BINARY)) < 0)
-      Error_abort2(_("Cannot open UPS port %s: %s\n"), opendev, strerror(errno));
+      Error_abort2("Cannot open UPS port %s: %s\n", opendev, strerror(errno));
 
    /* Cancel the no delay we just set */
    cmd = fcntl(ups->fd, F_GETFL, 0);
@@ -142,21 +142,9 @@ int apcsmart_ups_setup(UPSINFO *ups)
    if (ups->fd == -1)
       return 1;                    /* we must be a slave */
 
-   /*
-    * The following enables communcations with the
-    * BackUPS Pro models in Smart Mode.
-    */
-   switch (ups->cable.type) {
-   case APC_940_0095A:
-   case APC_940_0095B:
-   case APC_940_0095C:
-      /* Have to clear RTS line to access the serial cable mode PnP */
-      (void)ioctl(ups->fd, TIOCMBIC, &rts_bit);
-      break;
-
-   default:
-      break;
-   }
+   /* Have to clear RTS line to access the serial cable mode PnP on BKPro */
+   /* Shouldn't hurt on other cables, so just do it all the time. */
+   ioctl(ups->fd, TIOCMBIC, &rts_bit);
 
    write(ups->fd, &a, 1);          /* This one might not work, if UPS is */
    sleep(1);                       /* in an unstable communication state */
@@ -179,9 +167,9 @@ int apcsmart_ups_setup(UPSINFO *ups)
       sleep(1);
    }
    Error_abort0(
-      _("PANIC! Cannot communicate with UPS via serial port.\n"
-        "Please make sure the port specified on the DEVICE directive is correct,\n"
-        "and that your cable specification on the UPSCABLE directive is correct.\n"));
+      "PANIC! Cannot communicate with UPS via serial port.\n"
+      "Please make sure the port specified on the DEVICE directive is correct,\n"
+      "and that your cable specification on the UPSCABLE directive is correct.\n");
 
  out:
    return 1;
