@@ -44,7 +44,7 @@ extern int dumb_ups_check_state(UPSINFO *ups);
 extern int dumb_ups_open(UPSINFO *ups);
 extern int dumb_ups_close(UPSINFO *ups);
 extern int dumb_ups_setup(UPSINFO *ups);
-extern int dumb_ups_program_eeprom(UPSINFO *ups, int command, char *data);
+extern int dumb_ups_program_eeprom(UPSINFO *ups, int command, const char *data);
 extern int dumb_ups_entry_point(UPSINFO *ups, int command, void *data);
 
 #endif   /* _DUMB_H */
