@@ -164,7 +164,7 @@ static bool pcnet_process_data(UPSINFO* ups, const char *key, const char *value)
       break;
    case CI_LQUAL:
       Dmsg1(80, "Got CI_LQUAL: %s\n", value);
-      strncpy(ups->linequal, value, sizeof(ups->linequal));
+      astrncpy(ups->linequal, value, sizeof(ups->linequal));
       break;
    case CI_WHY_BATT:
       Dmsg1(80, "Got CI_WHY_BATT: %s\n", value);
@@ -248,7 +248,7 @@ static bool pcnet_process_data(UPSINFO* ups, const char *key, const char *value)
        */
    case CI_SENS:
       Dmsg1(80, "Got CI_SENS: %s\n", value);
-      strncpy(ups->sensitivity, value, sizeof(ups->sensitivity));
+      astrncpy(ups->sensitivity, value, sizeof(ups->sensitivity));
       break;
    case CI_DWAKE:
       Dmsg1(80, "Got CI_DWAKE: %s\n", value);
@@ -272,7 +272,7 @@ static bool pcnet_process_data(UPSINFO* ups, const char *key, const char *value)
       break;
    case CI_DALARM:
       Dmsg1(80, "Got CI_DALARM: %s\n", value);
-      strncpy(ups->beepstate, value, sizeof(ups->beepstate));
+      astrncpy(ups->beepstate, value, sizeof(ups->beepstate));
       break;
    case CI_DLBATT:
       Dmsg1(80, "Got CI_DLBATT: %s\n", value);
@@ -281,23 +281,23 @@ static bool pcnet_process_data(UPSINFO* ups, const char *key, const char *value)
    case CI_IDEN:
       Dmsg1(80, "Got CI_IDEN: %s\n", value);
       if (ups->upsname[0] == 0)
-         strncpy(ups->upsname, value, sizeof(ups->upsname));
+         astrncpy(ups->upsname, value, sizeof(ups->upsname));
       break;
    case CI_STESTI:
       Dmsg1(80, "Got CI_STESTI: %s\n", value);
-      strncpy(ups->selftest, value, sizeof(ups->selftest));
+      astrncpy(ups->selftest, value, sizeof(ups->selftest));
       break;
    case CI_MANDAT:
       Dmsg1(80, "Got CI_MANDAT: %s\n", value);
-      strncpy(ups->birth, value, sizeof(ups->birth));
+      astrncpy(ups->birth, value, sizeof(ups->birth));
       break;
    case CI_SERNO:
       Dmsg1(80, "Got CI_SERNO: %s\n", value);
-      strncpy(ups->serial, value, sizeof(ups->serial));
+      astrncpy(ups->serial, value, sizeof(ups->serial));
       break;
    case CI_BATTDAT:
       Dmsg1(80, "Got CI_BATTDAT: %s\n", value);
-      strncpy(ups->battdat, value, sizeof(ups->battdat));
+      astrncpy(ups->battdat, value, sizeof(ups->battdat));
       break;
    case CI_NOMOUTV:
       Dmsg1(80, "Got CI_NOMOUTV: %s\n", value);
@@ -309,7 +309,7 @@ static bool pcnet_process_data(UPSINFO* ups, const char *key, const char *value)
       break;
    case CI_REVNO:
       Dmsg1(80, "Got CI_REVNO: %s\n", value);
-      strncpy(ups->firmrev, value, sizeof(ups->firmrev));
+      astrncpy(ups->firmrev, value, sizeof(ups->firmrev));
       break;
    case CI_EXTBATTS:
       Dmsg1(80, "Got CI_EXTBATTS: %s\n", value);
@@ -321,11 +321,11 @@ static bool pcnet_process_data(UPSINFO* ups, const char *key, const char *value)
       break;
    case CI_UPSMODEL:
       Dmsg1(80, "Got CI_UPSMODEL: %s\n", value);
-      strncpy(ups->upsmodel, value, sizeof(ups->upsmodel));
+      astrncpy(ups->upsmodel, value, sizeof(ups->upsmodel));
       break;
    case CI_EPROM:
       Dmsg1(80, "Got CI_EPROM: %s\n", value);
-      strncpy(ups->eprom, value, sizeof(ups->eprom));
+      astrncpy(ups->eprom, value, sizeof(ups->eprom));
       break;
    default:
       Dmsg1(100, "Unknown CI (%d)\n", ci);
@@ -661,9 +661,6 @@ int pcnet_ups_open(UPSINFO *ups)
       Error_abort1("Cannot bind socket (%d)\n", errno);
    }
 
-   /* Cheat and fixup CI_UPSMODEL to match PCNET */
-   ups->UPS_Cmd[CI_UPSMODEL] = 0x01;
-
    /* Reset datatime to now */
    time(&my_data->datatime);
 
