@@ -19,7 +19,7 @@ extern int pcnet_ups_check_state(UPSINFO *ups);
 extern int pcnet_ups_open(UPSINFO *ups);
 extern int pcnet_ups_close(UPSINFO *ups);
 extern int pcnet_ups_setup(UPSINFO *ups);
-extern int pcnet_ups_program_eeprom(UPSINFO *ups, int command, char *data);
+extern int pcnet_ups_program_eeprom(UPSINFO *ups, int command, const char *data);
 extern int pcnet_ups_entry_point(UPSINFO *ups, int command, void *data);
 
 #endif   /* _PCNET_H */
