@@ -57,24 +57,24 @@ static const GENINFO onoroff[] = {
 
 static const GENINFO cables[] = {
    { "simple",         "Custom Cable Simple",  CUSTOM_SIMPLE },
-   { "smart",          "Custom Cable Smart",   CUSTOM_SMART },
-   { "ether",          "Ethernet Link",        APC_NET },
+   { "smart",          "Custom Cable Smart",   CABLE_SMART   },
+   { "ether",          "Ethernet Link",        APC_NET       },
    { "940-0119A",      "APC Cable 940-0119A",  APC_940_0119A },
    { "940-0127A",      "APC Cable 940-0127A",  APC_940_0127A },
    { "940-0128A",      "APC Cable 940-0128A",  APC_940_0128A },
    { "940-0020B",      "APC Cable 940-0020B",  APC_940_0020B },
    { "940-0020C",      "APC Cable 940-0020C",  APC_940_0020C },
    { "940-0023A",      "APC Cable 940-0023A",  APC_940_0023A },
-   { "940-0024B",      "APC Cable 940-0024B",  APC_940_0024B },
-   { "940-0024C",      "APC Cable 940-0024C",  APC_940_0024C },
-   { "940-1524C",      "APC Cable 940-1524C",  APC_940_1524C },
-   { "940-0024G",      "APC Cable 940-0024G",  APC_940_0024G },
+   { "940-0024B",      "APC Cable 940-0024B",  CABLE_SMART   },
+   { "940-0024C",      "APC Cable 940-0024C",  CABLE_SMART   },
+   { "940-1524C",      "APC Cable 940-1524C",  CABLE_SMART   },
+   { "940-0024G",      "APC Cable 940-0024G",  CABLE_SMART   },
    { "940-0095A",      "APC Cable 940-0095A",  APC_940_0095A },
    { "940-0095B",      "APC Cable 940-0095B",  APC_940_0095B },
    { "940-0095C",      "APC Cable 940-0095C",  APC_940_0095C },
-   { "MAM-04-02-2000", "MAM Cable 04-02-2000", MAM_CABLE},
+   { "MAM-04-02-2000", "MAM Cable 04-02-2000", MAM_CABLE     },
    { "usb",            "USB Cable",            USB_CABLE     },
-   { NULL,             "*invalid-cable*",      NO_CABLE  },
+   { NULL,             "*invalid-cable*",      NO_CABLE      },
 };
 
 static const GENINFO upsclasses[] = {
@@ -100,21 +100,6 @@ static const GENINFO modes[] = {
 };
 
 static const GENINFO types[] = {
-   /* FIXME (adk): It has been long enough...time to kill these */
-   { "backups",       "BackUPS",                   BK },
-   { "sharebasic",    "ShareUPS Basic Port",       SHAREBASIC },
-   { "backupspro",    "BackUPS Pro",               BKPRO },
-   { "smartvsups",    "SmartUPS VS",               VS },
-   { "newbackupspro", "Smarter BackUPS Pro",       NBKPRO },
-   { "backupspropnp", "Smarter BackUPS Pro",       NBKPRO },
-   { "smartups",      "SmartUPS",                  SMART },
-   { "matrixups",     "MatrixUPS",                 MATRIX },
-   { "sharesmart",    "ShareUPS Advanced Port",    SHARESMART },
-
-   /*
-    * Below are the new "drivers" entries. Entries above with time (long)
-    * will go away.
-    */
    { "dumb",     "DUMB UPS Driver",     DUMB_UPS },
    { "apcsmart", "APC Smart UPS (any)", APCSMART_UPS },
    { "usb",      "USB UPS Driver",      USB_UPS },
@@ -221,7 +206,7 @@ static int obsolete(UPSINFO *ups, int offset, const GENINFO * junk, const char *
 
    fprintf(stderr, "%s\n", msg);
    if (!offset) {
-      fprintf(stderr, _("error ignored.\n"));
+      fprintf(stderr, "error ignored.\n");
       return SUCCESS;
    }
    
@@ -239,7 +224,7 @@ static int start_ups(UPSINFO *ups, int offset, const GENINFO * size, const char
    /* Verify that we don't already have an UPS with the same name. */
    for (ups = NULL; (ups = getNextUps(ups)) != NULL;)
       if (strncmp(x, ups->upsname, UPSNAMELEN) == 0) {
-         fprintf(stderr, _("%s: duplicate upsname [%s] in config file.\n"),
+         fprintf(stderr, "%s: duplicate upsname [%s] in config file.\n",
             argvalue, ups->upsname);
          return FAILURE;
       }
@@ -248,7 +233,7 @@ static int start_ups(UPSINFO *ups, int offset, const GENINFO * size, const char
    ups = new_ups();
 
    if (ups == NULL) {
-      Error_abort1(_("%s: not enough memory.\n"), argvalue);
+      Error_abort1("%s: not enough memory.\n", argvalue);
       return FAILURE;
    }
 
@@ -270,12 +255,12 @@ static int end_ups(UPSINFO *ups, int offset, const GENINFO * size, const char *v
       return FAILURE;
 
    if (ups == NULL) {
-      fprintf(stderr, _("%s: upsname [%s] mismatch in config file.\n"), argvalue, x);
+      fprintf(stderr, "%s: upsname [%s] mismatch in config file.\n", argvalue, x);
       return FAILURE;
    }
 
    if (strncmp(x, ups->upsname, UPSNAMELEN) != 0) {
-      fprintf(stderr, _("%s: upsname [%s] mismatch in config file.\n"),
+      fprintf(stderr, "%s: upsname [%s] mismatch in config file.\n",
          argvalue, ups->upsname);
       return FAILURE;
    }
@@ -305,7 +290,7 @@ static int match_range(UPSINFO *ups, int offset, const GENINFO * vs, const char
 
    if (!vs) {
       /* Shouldn't ever happen so abort if it ever does. */
-      Error_abort1(_("%s: Bogus configuration table! Fix and recompile.\n"),
+      Error_abort1("%s: Bogus configuration table! Fix and recompile.\n",
          argvalue);
    }
 
@@ -325,9 +310,9 @@ static int match_range(UPSINFO *ups, int offset, const GENINFO * vs, const char
        * print error message (and log it).
        */
       log_event(ups, LOG_WARNING,
-         _("%s: Bogus configuration value (%s)\n"), argvalue, vs->long_name);
+         "%s: Bogus configuration value (%s)\n", argvalue, vs->long_name);
       fprintf(stderr,
-         _("%s: Bogus configuration value (%s)\n"), argvalue, vs->long_name);
+         "%s: Bogus configuration value (%s)\n", argvalue, vs->long_name);
       return FAILURE;
 
    }
@@ -354,7 +339,7 @@ static int match_index(UPSINFO *ups, int offset, const GENINFO * vs, const char
 
    if (!vs) {
       /* Shouldn't ever happen so abort if it ever does. */
-      Error_abort1(_("%s: Bogus configuration table! Fix and recompile.\n"),
+      Error_abort1("%s: Bogus configuration table! Fix and recompile.\n",
          argvalue);
    }
 
@@ -371,9 +356,9 @@ static int match_index(UPSINFO *ups, int offset, const GENINFO * vs, const char
        * print error message (and log it).
        */
       log_event(ups, LOG_WARNING,
-         _("%s: Bogus configuration value (%s)\n"), argvalue, vs->long_name);
+         "%s: Bogus configuration value (%s)\n", argvalue, vs->long_name);
       fprintf(stderr,
-         _("%s: Bogus configuration value (%s)\n"), argvalue, vs->long_name);
+         "%s: Bogus configuration value (%s)\n", argvalue, vs->long_name);
       return FAILURE;
 
    }
@@ -681,7 +666,7 @@ void check_for_config(UPSINFO *ups, char *cfgfile)
    int erpos = 0;
 
    if ((apcconf = fopen(cfgfile, "r")) == NULL) {
-      Error_abort2(_("Error opening configuration file (%s): %s\n"),
+      Error_abort2("Error opening configuration file (%s): %s\n",
          cfgfile, strerror(errno));
    }
    astrncpy(ups->configfile, cfgfile, sizeof(ups->configfile));
@@ -694,13 +679,13 @@ void check_for_config(UPSINFO *ups, char *cfgfile)
        * They never match so don't even compare them.
        */
       if (strncmp(line, APC_CONFIG_MAGIC, sizeof(APC_CONFIG_MAGIC) - 1) != 0) {
-         fprintf(stderr, _("%s: Warning: old configuration file found.\n\n"
+         fprintf(stderr, "%s: Warning: old configuration file found.\n\n"
                "%s: Expected: \"%s\"\n"
                "%s: Found:    \"%s\"\n\n"
                "%s: Please check new file format and\n"
                "%s: modify accordingly the first line\n"
                "%s: of config file.\n\n"
-               "%s: Processing config file anyway.\n"),
+               "%s: Processing config file anyway.\n",
             argvalue,
             argvalue, APC_CONFIG_MAGIC,
             argvalue, line, argvalue, argvalue, argvalue, argvalue);
@@ -722,7 +707,7 @@ jump_into_the_loop:
       if (ParseConfig(ups, line)) {
          errors++;
          Dmsg1(100, "%s\n", line);
-         Dmsg2(100, _("Parsing error at line %d of config file %s.\n"), erpos, cfgfile);
+         Dmsg2(100, "Parsing error at line %d of config file %s.\n", erpos, cfgfile);
       }
    }
 
@@ -751,18 +736,33 @@ jump_into_the_loop:
       ups->runtime = 5;
    }
 
-   if ((ups->cable.type < CUSTOM_SMART) && ups->mode.type >= BKPRO) {
-      fprintf(stderr, _("%s: Error :: Changing UPSTYPE from %s "),
-         argvalue, ups->mode.long_name);
-
-      /* No errors expected from this operation. */
-      errors += match_range(ups, WHERE(mode), types, "backups");
-
-      fprintf(stderr, _("to %s due wrong Cable of Smart Signals.\n\a"),
-         ups->mode.long_name);
-
-      if (errors)
-         Error_abort0(_("Lookup operation failed: bad 'types' table\n"));
+   // Sanitize cable type & UPS mode. Since UPSTYPE (aka mode) and UPSCABLE
+   // can contradict eachother, the rule is that UPSTYPE wins. In all cases
+   // except Dumb we can determine cable type from mode so we ignore user's 
+   // configured UPSCABLE and force it ourselves. In the case of Dumb UPSes we 
+   // just ensure they picked a simple cable type.
+   switch (ups->mode.type)
+   {
+   case USB_UPS:
+      match_range(ups, WHERE(cable), cables, "usb");
+      break;
+   case SNMPLITE_UPS:
+   case SNMP_UPS: 
+   case PCNET_UPS:
+   case NETWORK_UPS:
+      match_range(ups, WHERE(cable), cables, "ether");
+      break;
+   case APCSMART_UPS:
+      match_range(ups, WHERE(cable), cables, "smart");
+      break;
+   case DUMB_UPS:
+      // Abort if user specified dumb UPS type with smart cable
+      if (ups->cable.type >= CABLE_SMART)
+         Error_abort0("Invalid cable specified for Dumb UPS\n");
+      break;
+   case TEST_UPS:
+      // Allow anything in test mode
+      break;
    }
 
    /*
@@ -823,7 +823,7 @@ jump_into_the_loop:
 
 bail_out:
    if (errors)
-      error_exit(_("Terminating due to configuration file errors.\n"));
+      error_exit("Terminating due to configuration file errors.\n");
 
    return;
 }
